==> huggingface_client-1.1.0.tar.gz: example/vision/inference_image_classification_api.dart <==
/*
 * Package : huggingface_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 02/08/2023
 * Copyright :  S.Hamblett
 */

import 'dart:io';

import 'package:huggingface_client/huggingface_client.dart';
import '../api_key.dart';

/// Examples of how to use the Hugging Face Inference API to perform basic
/// model tasks.

void main() async {
  // Get an inference client with your Hugging Face API key as authentication.
  final client = HuggingFaceClient.getInferenceClient(
      apiKey, HuggingFaceClient.inferenceBasePath);

  // Get an instance of the inference API using our client
  final apiInstance = InferenceApi(client);

  //
  // Inference Vision Image Classification task
  //

  // Assumes you are running the example from the project root i.e
  // 'dart example/vision/inference_image_classification_api.dart'
  final imageFilePath =
      '${Directory.current.path}${Platform.pathSeparator}example${Platform.pathSeparator}'
      'vision${Platform.pathSeparator}test${Platform.pathSeparator}flower.jpg';
  final imageFile = File(imageFilePath);
  final imageFileContents = imageFile.readAsBytesSync();
  imageFileContents.buffer.asByteData();
  print('');
  print('*** Inference API Vision Image Classification task ***');
  print('');
  try {
    final result = await apiInstance.queryVisionImageClassification(
        imageFile: imageFileContents, model: 'google/vit-base-patch16-224');
    if (result!.isNotEmpty) {
      for (final row in result) {
        print(row);
      }
    } else {
      print('Inference Vision Image Classification result is empty');
    }
  } catch (e) {
    print(
        'Exception when calling Vision Inference Image Classification API : $e - exiting');
    return;
  }

  return;
}

==> huggingface_client-1.2.1.tar.gz: example/vision/inference_image_classification_api.dart <==
/*
 * Package : huggingface_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 02/08/2023
 * Copyright :  S.Hamblett
 */

import 'dart:io';

import 'package:huggingface_client/huggingface_client.dart';
import '../api_key.dart';

/// Examples of how to use the Hugging Face Inference API to perform basic
/// model tasks.

void main() async {
  // Get an inference client with your Hugging Face API key as authentication.
  final client = HuggingFaceClient.getInferenceClient(
      inferenceApiKey, HuggingFaceClient.inferenceBasePath);

  // Get an instance of the inference API using our client
  final apiInstance = InferenceApi(client);

  //
  // Inference Vision Image Classification task
  //

  // Assumes you are running the example from the project root i.e
  // 'dart example/vision/inference_image_classification_api.dart'
  final imageFilePath =
      '${Directory.current.path}${Platform.pathSeparator}example${Platform.pathSeparator}'
      'vision${Platform.pathSeparator}test${Platform.pathSeparator}flower.jpg';
  final imageFile = File(imageFilePath);
  final imageFileContents = imageFile.readAsBytesSync();
  imageFileContents.buffer.asByteData();
  print('');
  print('*** Inference API Vision Image Classification task ***');
  print('');
  try {
    final result = await apiInstance.queryVisionImageClassification(
        imageFile: imageFileContents, model: 'google/vit-base-patch16-224');
    if (result!.isNotEmpty) {
      for (final row in result) {
        print(row);
      }
    } else {
      print('Inference Vision Image Classification result is empty');
    }
  } catch (e) {
    print(
        'Exception when calling Vision Inference Image Classification API : $e - exiting');
    return;
  }

  return;
}
